@@ -1,16 +1,16 @@
 
 /*
  *  autogen.c
- *  $Id: autogen.c,v 4.18 2006/12/15 03:01:10 bkorb Exp $
+ *  $Id: autogen.c,v 4.21 2007/03/25 16:48:11 bkorb Exp $
  *
- *  Time-stamp:        "2006-12-14 18:17:30 bkorb"
- *  Last Committed:    $Date: 2006/12/15 03:01:10 $
+ *  Time-stamp:        "2007-03-25 07:47:12 bkorb"
+ *  Last Committed:    $Date: 2007/03/25 16:48:11 $
  *
  *  This is the main routine for autogen.
  */
 
 /*
- *  AutoGen copyright 1992-2006 Bruce Korb
+ *  AutoGen copyright 1992-2007 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -79,7 +79,7 @@ inner_main( int argc, char** argv )
     procState = PROC_STATE_LOAD_TPL;
 
     {
-        tTemplate* pTF = loadTemplate( pzTemplFileName );
+        tTemplate* pTF = loadTemplate(pzTemplFileName, NULL);
 
         procState = PROC_STATE_EMITTING;
         processTemplate( pTF );
@@ -490,7 +490,7 @@ ao_malloc (size_t sz)
 {
     void * res = malloc(sz);
     if (res == NULL) {
-        fprintf(stderr, "malloc of %d bytes failed\n", (int)sz);
+        fprintf(stderr, "malloc of %zd bytes failed\n", sz);
         exit( EXIT_FAILURE );
     }
     return res;
@@ -502,7 +502,7 @@ ao_realloc (void *p, size_t sz)
 {
     void * res = realloc(p, sz);
     if (res == NULL) {
-        fprintf(stderr, "realloc of %d bytes at 0x%p failed\n", (int)sz, p);
+        fprintf(stderr, "realloc of %zd bytes at 0x%p failed\n", sz, p);
         exit( EXIT_FAILURE );
     }
     return res;
