@@ -1,16 +1,16 @@
 
 /*
  *  expMake.c
- *  $Id: expMake.c,v 4.8 2006/09/24 02:58:59 bkorb Exp $
+ *  $Id: expMake.c,v 4.10 2007/04/28 22:19:23 bkorb Exp $
  *
- *  Time-stamp:        "2006-09-23 19:53:11 bkorb"
- *  Last Committed:    $Date: 2006/09/24 02:58:59 $
+ *  Time-stamp:        "2006-12-10 11:04:31 bkorb"
+ *  Last Committed:    $Date: 2007/04/28 22:19:23 $
  *
  *  This module implements Makefile construction functions.
  */
 
 /*
- *  AutoGen copyright 1992-2006 Bruce Korb
+ *  AutoGen copyright 1992-2007 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -120,7 +120,7 @@ ag_scm_makefile_script( SCM text )
     }
 
     if (*pzText == NUL)
-        return AG_SCM_STR02SCM( "" );
+        return AG_SCM_STR02SCM(zNil);
 
     {
         char*  pz  = strchr( pzText, '\n' );
