@@ -1,9 +1,9 @@
 
 /*
- *  $Id: expPrint.c,v 4.14 2006/09/24 02:58:59 bkorb Exp $
+ *  $Id: expPrint.c,v 4.18 2007/04/28 22:19:23 bkorb Exp $
  *
- *  Time-stamp:        "2006-09-23 19:52:48 bkorb"
- *  Last Committed:    $Date: 2006/09/24 02:58:59 $
+ *  Time-stamp:        "2007-03-25 08:02:07 bkorb"
+ *  Last Committed:    $Date: 2007/04/28 22:19:23 $
  *
  *  The following code is necessary because the user can give us
  *  a printf format requiring a string pointer yet fail to provide
@@ -13,7 +13,7 @@
  */
 
 /*
- *  AutoGen copyright 1992-2006 Bruce Korb
+ *  AutoGen copyright 1992-2007 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -33,6 +33,8 @@
  */
 
 static sigjmp_buf printJumpEnv;
+static int        printJumpSignal = 0;
+
 static void   printFault( int sig );
 static ssize_t safePrintf( char** pzBuf, char* pzFmt, void** argV );
 
@@ -48,6 +50,7 @@ safePrintf( char** ppzBuf, char* pzFmt, void** argV );
 static void
 printFault( int sig )
 {
+    printJumpSignal = sig;
     siglongjmp( printJumpEnv, sig );
 }
 
@@ -77,16 +80,15 @@ safePrintf( char** ppzBuf, char* pzFmt, void** argV )
         sigaction( SIGSEGV, &sa, &saSave2 );
     }
 
-    /*
-     *  IF the sprintfv call below is going to address fault,
-     *  THEN ...
-     */
     {
         tSCC zBadArgs[] = "Bad args to sprintf";
         tSCC zBadFmt[]  = "%s ERROR:  %s processing printf format:\n\t%s\n";
-        int  faultType  = sigsetjmp( printJumpEnv, 0 );
 
-        if (faultType != 0) {
+        /*
+         *  IF the sprintfv call below is going to address fault,
+         *  THEN ...
+         */
+        if (sigsetjmp( printJumpEnv, 0 ) != 0) {
 #ifndef HAVE_STRSIGNAL
             extern char* strsignal(int signo);
 #endif
@@ -95,7 +97,8 @@ safePrintf( char** ppzBuf, char* pzFmt, void** argV )
              *  THEN perform that fprintf
              */
             if (sigsetjmp( printJumpEnv, 0 ) == 0)
-                fprintf(pfTrace, zBadFmt, pzProg, strsignal(faultType), pzFmt);
+                fprintf(pfTrace, zBadFmt, pzProg,
+                        strsignal(printJumpSignal), pzFmt);
 
             /*
              *  The "sprintfv" command below faulted, so we exit
@@ -106,8 +109,7 @@ safePrintf( char** ppzBuf, char* pzFmt, void** argV )
 #endif /* ! defined(DEBUG_ENABLED) */
 
     {
-        size_t printSize = asprintfv( ppzBuf, pzFmt,
-                                      (snv_constpointer*)argV );
+        int printSize = asprintfv( ppzBuf, pzFmt, (snv_constpointer*)argV );
         if ((printSize & ~0xFFFFFU) != 0) /* 1MB max */
             AG_ABEND( aprf( "asprintfv returned 0x%08X\n", printSize ));
 
@@ -308,7 +310,7 @@ ag_scm_hide_email( SCM display, SCM eaddr )
 
     pzScan += sprintf( pzScan, zEnd, pzDisp );
 
-    return AG_SCM_STR2SCM( pzRes, (unsigned)(pzScan - pzRes));
+    return AG_SCM_STR2SCM( pzRes, (size_t)(pzScan - pzRes));
 }
 
 
