@@ -1,15 +1,15 @@
 
 /*
- *  $Id: funcDef.c,v 4.16 2006/09/24 02:59:00 bkorb Exp $
+ *  $Id: funcDef.c,v 4.18 2007/04/28 22:19:23 bkorb Exp $
  *
- *  Time-stamp:        "2006-09-23 19:51:46 bkorb"
- *  Last Committed:    $Date: 2006/09/24 02:59:00 $
+ *  Time-stamp:        "2006-11-26 15:55:10 bkorb"
+ *  Last Committed:    $Date: 2007/04/28 22:19:23 $
  *
  *  This module implements the DEFINE text function.
  */
 
 /*
- *  AutoGen copyright 1992-2006 Bruce Korb
+ *  AutoGen copyright 1992-2007 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -244,7 +244,7 @@ parseMacroArgs( tTemplate* pT, tMacro* pMac )
              */
             if ((pzScan - pDL->pzExpr) < 24) {
                 char* pz = (char*)AGALOC( 24, "quoted string" );
-                memcpy((void*)pz, pDL->pzExpr, (unsigned)(pzScan - pDL->pzExpr));
+                memcpy((void*)pz, pDL->pzExpr, (size_t)(pzScan - pDL->pzExpr));
                 pDL->pzExpr = pz;
                 manageAllocatedData( pz );
             }
@@ -452,7 +452,8 @@ build_defs( int defCt, tDefList* pList )
             }
             else if (AG_SCM_NUM_P( res )) {
                 pList->de.val.pzText = AGALOC( 16, "number buf" );
-                snprintf( pList->de.val.pzText, 16, "%ld", gh_scm2ulong( res ));
+                snprintf(pList->de.val.pzText, (size_t)16, "%ld",
+                         gh_scm2ulong( res ));
             }
             else
                 AGDUPSTR( pList->de.val.pzText, zNil, "empty string" );
