@@ -1,12 +1,15 @@
 
 /*
- *  $Id: funcFor.c,v 4.11 2006/06/24 23:36:07 bkorb Exp $
+ *  $Id: funcFor.c,v 4.17 2007/04/28 22:19:23 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-11-26 17:44:35 bkorb"
+ *  Last Committed:    $Date: 2007/04/28 22:19:23 $
  *
  *  This module implements the FOR text macro.
  */
 
 /*
- *  AutoGen copyright 1992-2006 Bruce Korb
+ *  AutoGen copyright 1992-2007 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -47,7 +50,7 @@ doForEach( tTemplate*   pT,
            tDefEntry*   pFoundDef );
 
 static void
-load_ForIn( tCC* pzSrc, u_int srcLen, tTemplate* pT, tMacro* pMac );
+load_ForIn( tCC* pzSrc, size_t srcLen, tTemplate* pT, tMacro* pMac );
 /* = = = END-STATIC-FORWARD = = = */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
@@ -361,11 +364,11 @@ doForByStep( tTemplate* pT,
         if (loopLimit-- < 0) {
             fprintf( pfTrace, "too many FOR iterations in %s line %d\n",
                      pT->pzTplName, pMac->lineNo );
-            fprintf( pfTrace, "\texiting FOR %s from %d to %d "
-                     "by %d:\n\tmore than %ld iterations\n",
+            fprintf( pfTrace, "\texiting FOR %s from %d to %d by %d:\n"
+                     "\tmore than %d iterations\n",
                      pT->pzTemplText + pMac->ozText,
                      pFS->for_from, pFS->for_to, pFS->for_by,
-                     OPT_VALUE_LOOP_LIMIT );
+                     (int)OPT_VALUE_LOOP_LIMIT );
             break;
         }
 
@@ -495,7 +498,7 @@ doForEach( tTemplate*   pT,
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 static void
-load_ForIn( tCC* pzSrc, u_int srcLen, tTemplate* pT, tMacro* pMac )
+load_ForIn( tCC* pzSrc, size_t srcLen, tTemplate* pT, tMacro* pMac )
 {
     char* pzName = pT->pzTemplText + pMac->ozName;
     int   ix     = 0;
@@ -760,8 +763,8 @@ tMacro*
 mLoad_For( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 {
     char*   pzCopy = pT->pNext; /* next text dest   */
-    tCC*    pzSrc  = (const char*)pMac->ozText; /* macro text */
-    int     srcLen = (int)pMac->res;            /* macro len  */
+    tCC*    pzSrc  = (char const*)pMac->ozText; /* macro text */
+    size_t  srcLen = (size_t)pMac->res;         /* macro len  */
     tMacro* pEndMac;
 
     /*
@@ -811,22 +814,25 @@ mLoad_For( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     while (isspace( *pzSrc )) pzSrc++;
     srcLen -= pzSrc - (char*)pMac->ozText;
 
-    /*
+    /* * * * *
+     *
      *  No source -> zero offset to text
      */
-    if (srcLen <= 0) {
+    if ((ssize_t)srcLen <= 0) {
         pMac->ozText = 0;
     }
 
-    /*
+    /* * * * *
+     *
      *  FOR foo IN ...  -> no text, but we create an array of text values
      */
     else if (   (strneqvcmp( pzSrc, "in", 2 ) == 0)
              && isspace( pzSrc[2] )) {
-        load_ForIn( pzSrc, (unsigned)srcLen, pT, pMac );
+        load_ForIn( pzSrc, srcLen, pT, pMac );
     }
 
-    /*
+    /* * * * *
+     *
      *  *EITHER* a:  FOR foo "<<separator>>"
      *  *OR*         FOR foo (scheme ...) ...
      */
@@ -840,6 +846,9 @@ mLoad_For( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
         if ((*pzCopied == '"') || (*pzCopied == '\''))
             spanQuote( pzCopied );
     }
+    /*
+     * * * * */
+
     pT->pNext = pzCopy;
 
     pEndMac = parseTemplate( pMac + 1, ppzScan );
@@ -855,7 +864,6 @@ mLoad_For( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/funcFor.c */
