@@ -1,7 +1,7 @@
 
 /*
- *  $Id: autoopts.c,v 4.13 2006/07/15 22:17:36 bkorb Exp $
- *  Time-stamp:      "2006-07-15 13:54:08 bkorb"
+ *  $Id: autoopts.c,v 4.25 2007/04/15 19:01:18 bkorb Exp $
+ *  Time-stamp:      "2007-04-15 11:10:40 bkorb"
  *
  *  This file contains all of the routines that must be linked into
  *  an executable to use the generated option processing.  The optional
@@ -10,7 +10,7 @@
  */
 
 /*
- *  Automated Options copyright 1992-2006 Bruce Korb
+ *  Automated Options copyright 1992-2007 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -52,26 +52,7 @@
  * If you do not wish that, delete this exception notice.
  */
 
-#ifndef HAVE_PATHFIND
-#  include "compat/pathfind.c"
-#endif
-
-#ifndef HAVE_SNPRINTF
-#  include "compat/snprintf.c"
-#endif
-
-#ifndef HAVE_STRDUP
-#  include "compat/strdup.c"
-#endif
-
-#ifndef HAVE_STRCHR
-#  include "compat/strchr.c"
-#endif
-
-static const char zNil[] = "";
-
-#define SKIP_RC_FILES(po) \
-    DISABLED_OPT(&((po)->pOptDesc[ (po)->specOptIdx.save_opts+1]))
+static char const zNil[] = "";
 
 /* = = = START-STATIC-FORWARD = = = */
 /* static forward declarations maintained by :mkfwd */
@@ -88,6 +69,72 @@ static int
 checkConsistency( tOptions* pOpts );
 /* = = = END-STATIC-FORWARD = = = */
 
+LOCAL void *
+ao_malloc( size_t sz )
+{
+    void * res = malloc(sz);
+    if (res == NULL) {
+        fprintf( stderr, "malloc of %d bytes failed\n", (int)sz );
+        exit( EXIT_FAILURE );
+    }
+    return res;
+}
+#undef  malloc
+#define malloc(_s) ao_malloc(_s)
+
+LOCAL void *
+ao_realloc( void *p, size_t sz )
+{
+    void * res = realloc(p, sz);
+    if (res == NULL) {
+        fprintf( stderr, "realloc of %d bytes at 0x%p failed\n", (int)sz, p );
+        exit( EXIT_FAILURE );
+    }
+    return res;
+}
+#undef  realloc
+#define realloc(_p,_s) ao_realloc(_p,_s)
+
+
+LOCAL void
+ao_free( void *p )
+{
+    if (p != NULL)
+        free(p);
+}
+#undef  free
+#define free(_p) ao_free(_p)
+
+
+LOCAL char *
+ao_strdup( char const *str )
+{
+    char * res = strdup(str);
+    if (res == NULL) {
+        fprintf( stderr, "strdup of %d byte string failed\n", (int)strlen(str) );
+        exit( EXIT_FAILURE );
+    }
+    return res;
+}
+#undef  strdup
+#define strdup(_p) ao_strdup(_p)
+
+#ifndef HAVE_PATHFIND
+#  include "compat/pathfind.c"
+#endif
+
+#ifndef HAVE_SNPRINTF
+#  include "compat/snprintf.c"
+#endif
+
+#ifndef HAVE_STRDUP
+#  include "compat/strdup.c"
+#endif
+
+#ifndef HAVE_STRCHR
+#  include "compat/strchr.c"
+#endif
+
 /*
  *  handleOption
  *
@@ -103,8 +150,10 @@ handleOption( tOptions* pOpts, tOptState* pOptState )
      */
     tOptDesc* pOD = pOptState->pOD;
     tOptProc* pOP = pOD->pOptProc;
+    if (pOD->fOptState & OPTST_ALLOC_ARG)
+        AGFREE(pOD->optArg.argString);
 
-    pOD->pzLastArg =  pOptState->pzOptArg;
+    pOD->optArg.argString = pOptState->pzOptArg;
 
     /*
      *  IF we are presetting options, then we will ignore any un-presettable
@@ -169,7 +218,7 @@ handleOption( tOptions* pOpts, tOptState* pOptState )
          *  Copy the most recent option argument.  set membership state
          *  is kept in ``p->optCookie''.  Do not overwrite.
          */
-        p->pzLastArg = pOD->pzLastArg;
+        p->optArg.argString = pOD->optArg.argString;
         pOD = p;
 
     } else {
@@ -177,8 +226,8 @@ handleOption( tOptions* pOpts, tOptState* pOptState )
         pOD->optActualIndex = pOD->optIndex;
     }
 
-    pOD->fOptState &= OPTST_PERSISTENT;
-    pOD->fOptState |= (pOptState->flags & ~OPTST_PERSISTENT);
+    pOD->fOptState &= OPTST_PERSISTENT_MASK;
+    pOD->fOptState |= (pOptState->flags & ~OPTST_PERSISTENT_MASK);
 
     /*
      *  Keep track of count only for DEFINED (command line) options.
@@ -186,14 +235,17 @@ handleOption( tOptions* pOpts, tOptState* pOptState )
      */
     if (  (pOD->fOptState & OPTST_DEFINED)
        && (++pOD->optOccCt > pOD->optMaxCt)  )  {
-        const char* pzEqv =
-            (pOD->optEquivIndex != NO_EQUIVALENT) ? zEquiv : zNil;
 
         if ((pOpts->fOptSet & OPTPROC_ERRSTOP) != 0) {
-            const char* pzFmt = (pOD->optMaxCt > 1) ? zAtMost : zOnlyOne;
+            char const * pzEqv =
+                (pOD->optEquivIndex != NO_EQUIVALENT) ? zEquiv : zNil;
+
             fputs( zErrOnly, stderr );
-            fprintf( stderr, pzFmt, pOD->pz_Name, pzEqv,
-                     pOD->optMaxCt );
+
+            if (pOD->optMaxCt > 1)
+                fprintf(stderr, zAtMost, pOD->optMaxCt, pOD->pz_Name, pzEqv);
+            else
+                fprintf(stderr, zOnlyOne, pOD->pz_Name, pzEqv);
         }
 
         return FAILURE;
@@ -514,11 +566,13 @@ nextOption( tOptions* pOpts, tOptState* pOptState )
 {
     tSuccess res;
     enum { ARG_NONE, ARG_MAY, ARG_MUST } arg_type = ARG_NONE;
+    teOptArgType at;
 
     res = findOptDesc( pOpts, pOptState );
     if (! SUCCESSFUL( res ))
         return res;
-    pOptState->flags |= (pOptState->pOD->fOptState & OPTST_PERSISTENT);
+    pOptState->flags |= (pOptState->pOD->fOptState & OPTST_PERSISTENT_MASK);
+    at = OPTST_GET_ARGTYPE(pOptState->flags);
 
     /*
      *  Figure out what to do about option arguments.  An argument may be
@@ -528,7 +582,7 @@ nextOption( tOptions* pOpts, tOptState* pOptState )
      */
     if ((pOptState->flags & OPTST_DISABLED) != 0)
         arg_type = ARG_NONE;
-    else if (OPTST_GET_ARGTYPE(pOptState->flags) == OPARG_TYPE_NONE)
+    else if (at == OPARG_TYPE_NONE)
         arg_type = ARG_NONE;
     else if (pOptState->flags & OPTST_ARG_OPTIONAL)
         arg_type = ARG_MAY;
@@ -640,7 +694,7 @@ nextOption( tOptions* pOpts, tOptState* pOptState )
         case TOPT_DEFAULT:
             fputs( "AutoOpts lib error: defaulted to option with optional arg\n",
                    stderr );
-            exit( EXIT_FAILURE );
+            exit( EX_SOFTWARE );
         }
 
         /*
@@ -773,9 +827,22 @@ doRegularOpts( tOptions* pOpts )
 static tSuccess
 doPresets( tOptions* pOpts )
 {
+    tOptDesc * pOD = NULL;
+
     if (! SUCCESSFUL( doImmediateOpts( pOpts )))
         return FAILURE;
 
+    /*
+     *  IF this option set has a --save-opts option, then it also
+     *  has a --load-opts option.  See if a command line option has disabled
+     *  option presetting.
+     */
+    if (pOpts->specOptIdx.save_opts != 0) {
+        pOD = pOpts->pOptDesc + pOpts->specOptIdx.save_opts + 1;
+        if (DISABLED_OPT(pOD))
+            return SUCCESS;
+    }
+
     /*
      *  Until we return from this procedure, disable non-presettable opts
      */
@@ -784,13 +851,22 @@ doPresets( tOptions* pOpts )
      *  IF there are no config files,
      *  THEN do any environment presets and leave.
      */
-    if (  (pOpts->papzHomeList == NULL)
-       || SKIP_RC_FILES(pOpts) )  {
+    if (pOpts->papzHomeList == NULL) {
         doEnvPresets( pOpts, ENV_ALL );
     }
     else {
         doEnvPresets( pOpts, ENV_IMM );
-        internalFileLoad( pOpts );
+
+        /*
+         *  Check to see if environment variables have disabled presetting.
+         */
+        if ((pOD != NULL) && ! DISABLED_OPT(pOD))
+            internalFileLoad( pOpts );
+
+        /*
+         *  ${PROGRAM_LOAD_OPTS} value of "no" cannot disable other environment
+         *  variable options.  Only the loading of .rc files.
+         */
         doEnvPresets( pOpts, ENV_NON_IMM );
     }
     pOpts->fOptSet &= ~OPTPROC_PRESETTING;
@@ -875,9 +951,9 @@ checkConsistency( tOptions* pOpts )
 
             errCt++;
             if (pOD->optMinCt > 1)
-                fprintf( stderr, zNotEnough, pOD->pz_Name, pOD->optMinCt );
+                 fprintf( stderr, zNotEnough, pOD->pz_Name, pOD->optMinCt );
             else fprintf( stderr, zNeedOne, pOD->pz_Name );
-           } while (0);
+        } while (0);
 
         if (--oCt <= 0)
             break;
@@ -974,7 +1050,7 @@ optionProcess(
     char**     argVect )
 {
     if (! SUCCESSFUL( validateOptionsStruct( pOpts, argVect[0] )))
-        exit( EXIT_FAILURE );
+        exit( EX_SOFTWARE );
 
     /*
      *  Establish the real program name, the program full path,
@@ -1039,7 +1115,6 @@ optionProcess(
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of autoopts/autoopts.c */
