@@ -93,18 +93,15 @@ spec_init (void)
   if (!is_init)
     {
       extern spec_entry snv_default_spec_table[];
-      unsigned ix = 0;
+      unsigned ix;
 
       memset (spec_table, 0, sizeof (spec_table));
-      while (snv_default_spec_table[ix].spec_key != EOS)
+      for (ix = 0; snv_default_spec_table[ix].spec_key != EOS; ix++)
 	{
 	  unsigned hash = spec_hash (snv_default_spec_table[ix].spec_key);
 	  spec_table[hash] = snv_default_spec_table + ix;
-	  ix++;
 	}
-#ifdef SNV_LIBRARY_BUILD
-      snv_load_all_modules ();
-#endif
+
       is_init = SNV_TRUE;
     }
 }
@@ -133,10 +130,10 @@ spec_lookup (unsigned spec)
  * @fmt: the handler function to actually print the arguments to the specifier
  * @arg: the handler function to tell %printf about the types of the arguments
  *       to the specifier
- * 
+ *
  * Register the pair made of @fmt and @arg, so that it is called
  * when @spec is encountered in a format string.
- * 
+ *
  * Return value:
  * Returns %NULL if @func was not successfully registered, a
  * %spec_entry with the information on the function if it was.
@@ -208,15 +205,15 @@ call_argtype_function (
 
   else
     {
-      pinfo->spec  = (unsigned)*(pinfo->format);
+      pinfo->spec = (unsigned)*(pinfo->format);
       pinfo->extra = spec->user;
-      pinfo->type  = spec->type;
+      pinfo->type = spec->type;
 
       if (pinfo->argc > argindex)
-        n = spec->arg(pinfo, (unsigned)(pinfo->argc - argindex),
+        n = spec->arg(pinfo, (size_t) (pinfo->argc - argindex),
 		      *argtypes + argindex);
       else
-        n = spec->arg(pinfo, 0, NULL);
+        n = spec->arg(pinfo, (size_t)0, NULL);
 
       if (n < 0)
 	return n;
@@ -234,8 +231,8 @@ call_argtype_function (
           pinfo->spec     = (unsigned)*(pinfo->format);
           pinfo->extra    = spec->user;
           pinfo->type     = spec->type;
-          n = spec->arg(pinfo, (unsigned)n, *argtypes + argindex);
-	}
+          n = spec->arg(pinfo, (size_t)n, *argtypes + argindex);
+        }
     }
 
   if (!pinfo->dollar || !IS_MODIFIER (spec))
@@ -279,7 +276,7 @@ parser_reset (struct printf_info *pinfo)
 {
   pinfo->is_long_double = pinfo->is_char = pinfo->is_short =
     pinfo->is_long = pinfo->alt = pinfo->space = pinfo->left =
-    pinfo->showsign = pinfo->group = pinfo->wide = 
+    pinfo->showsign = pinfo->group = pinfo->wide =
     pinfo->width = pinfo->spec = 0;
 
   pinfo->state = SNV_STATE_BEGIN;
@@ -300,11 +297,11 @@ parser_reset (struct printf_info *pinfo)
  * @func2: function where error was detected, if supplied by compiler.
  * @func3: ")" if function is supplied by compiler.
  * @error_message: new error message to append to @pinfo.
- * 
+ *
  * The contents of @error_message are appended to the @pinfo internal
  * error string, so it is safe to pass static strings or recycle the
  * original when this function returns.
- * 
+ *
  * Return value:
  * The address of the full accumulated error message in @pinfo is
  * returned.
@@ -315,7 +312,7 @@ printf_error (struct printf_info *pinfo, const char *file, int line, const char
   int i;
   char *result;
   if (pinfo->error == NULL)
-    pinfo->error = filnew (NULL, 0);
+    pinfo->error = filnew (NULL, (size_t)0);
   else
     filccat (pinfo->error, '\n');
 
@@ -343,7 +340,7 @@ printf_error (struct printf_info *pinfo, const char *file, int line, const char
  * @format: a % delimited format string.
  * @n: the size of the @argtypes vector
  * @argtypes: a vector of ints, to be filled with the argument types from @format
- * 
+ *
  * Returns information about the number and types of
  * arguments expected by the template string @format.
  * The argument @n specifies the number of elements in the array
@@ -363,7 +360,7 @@ parse_printf_format (const char *format, int n, int *argtypes)
 {
   struct printf_info info;
 
-  return_val_if_fail (format != NULL, (size_t)(-1));
+  return_val_if_fail (format != NULL, (size_t)-1);
 
   parser_init (&info, format, NULL);
 
@@ -407,46 +404,46 @@ parse_printf_format (const char *format, int n, int *argtypes)
 	          argindex = info.dollar && !IS_MODIFIER (spec)
 			       ? info.dollar - 1 : info.argindex;
 
-		  /* ...and call the relevant handler.  */
-		  if (spec->arg)
-		    {
-                      info.spec  = (unsigned)*(info.format);
+                  /* ...and call the relevant handler.  */
+                  if (spec->arg)
+                    {
+                      info.spec = (unsigned)*(info.format);
                       info.extra = spec->user;
-                      info.type  = spec->type;
-                      status     = (*spec->arg) (&info, (unsigned)(n - argindex),
-                                                 argtypes + argindex);
-		    }
-		  else
-		    {
-		      status = 1;
-		      if (n > argindex)
-			argtypes[argindex] = spec->type;
-		    }
+                      info.type = spec->type;
+                      status = (*spec->arg) (&info, (size_t) (n - argindex),
+                                             argtypes + argindex);
+                    }
+                  else
+                    {
+                      status = 1;
+                      if (n > argindex)
+                        argtypes[argindex] = spec->type;
+                    }
 
-		  if (status < 0)
-		    goto error;
+                  if (status < 0)
+                    goto error;
 
-		  info.argc = MAX (info.argc, argindex + status);
-		  if (!info.dollar || !IS_MODIFIER (spec))
-		    info.argindex += status;
+                  info.argc = MAX (info.argc, argindex + status);
+                  if (!info.dollar || !IS_MODIFIER (spec))
+                    info.argindex += status;
 
-		  info.format++;
-		}
-	      while (IS_MODIFIER (spec));
-	      continue;
-	    }
+                  info.format++;
+                }
+              while (IS_MODIFIER (spec));
+              continue;
+            }
 
-	  /* An escaped CHAR_SPEC: ignore it (by falling through). */
-	  ++info.format;
+          /* An escaped CHAR_SPEC: ignore it (by falling through). */
+          ++info.format;
 
-	  /*NOBREAK*/
+          /*FALLTHROUGH*/
 
-        default:	/* Just a character: ignore it. */
-	  continue;
-	}
-     
-    error: 
-      /* Get here on error */ 
+        default:        /* Just a character: ignore it. */
+          continue;
+        }
+
+    error:
+      /* Get here on error */
       info.argc = -1;
       break;
     }
@@ -513,11 +510,11 @@ do_printfv (STREAM *stream, const char *format, union printf_arg const args[])
 		    }
 
 		  /* ...and call the relevant handler. */
-		  info.spec  = (unsigned)*(info.format);
+		  info.spec = (unsigned)*(info.format);
 		  info.extra = spec->user;
-		  info.type  = spec->type;
+		  info.type = spec->type;
 
-		  status = spec->arg ? (*spec->arg) (&info, 0, NULL) : 1;
+		  status = spec->arg ? (*spec->arg) (&info, (size_t)0, NULL) : 1;
 
 		  if (status < 0)
 		    goto error;
@@ -544,12 +541,13 @@ do_printfv (STREAM *stream, const char *format, union printf_arg const args[])
 	  /* An escaped CHAR_SPEC: ignore it (by falling through). */
 	  ++info.format;
 
-	  /*NOBREAK*/
+	  /*FALLTHROUGH*/
 
-	default:       /* Just a character: copy it. */
-	  SNV_EMIT (ch, stream, info.count);
-	  continue;
-	}
+        default:
+          /* Just a character: copy it. */
+          SNV_EMIT (ch, stream, info.count);
+          continue;
+        }
 
     error:
       /* Get here on error */
@@ -573,11 +571,11 @@ do_printfv (STREAM *stream, const char *format, union printf_arg const args[])
  * @stream: an initialised stream structure.
  * @format: a % delimited format string.
  * @args: a vector of argument addresses to match @format.
- * 
+ *
  * Format the elements of @args according to @format, and write
  * the results to @stream.  If @stream is %NULL, only count the
  * number of characters needed to output the format.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -600,54 +598,54 @@ stream_printfv (STREAM *stream, const char *format, snv_constpointer const *ap)
       int ch = (int) *info.format++;
 
       switch (ch)
-	{
-	case SNV_CHAR_SPEC:
-	  if (*info.format != SNV_CHAR_SPEC)
-	    {
-	      /* We found the start of a format specifier! */
-	      spec_entry *spec;
+        {
+        case SNV_CHAR_SPEC:
+          if (*info.format != SNV_CHAR_SPEC)
+            {
+              /* We found the start of a format specifier! */
+              spec_entry *spec;
 
-	      parser_reset (&info);
-	      do
-		{
-		  /* Until we fill the stream (or get some other
-		     exception) or one of the handlers tells us
-		     we have reached the end of the specifier... */
+              parser_reset (&info);
+              do
+                {
+                  /* Until we fill the stream (or get some other
+                     exception) or one of the handlers tells us
+                     we have reached the end of the specifier... */
 
-		  /* ...lookup the handler associated with the char
-		     we are looking at in the format string... */
-		  spec = spec_lookup ((unsigned)*(info.format));
-		  if (spec == NULL)
-		    {
-		      PRINTF_ERROR (&info, "unregistered specifier");
-		      goto error;
-		    }
+                  /* ...lookup the handler associated with the char
+                     we are looking at in the format string... */
+                  spec = spec_lookup ((unsigned)*(info.format));
+                  if (spec == NULL)
+                    {
+                      PRINTF_ERROR (&info, "unregistered specifier");
+                      goto error;
+                    }
 
-		  if (!IS_MODIFIER (spec) &&
-		      !(info.state & (SNV_STATE_BEGIN | SNV_STATE_SPECIFIER)))
-		    {
-		      PRINTF_ERROR (&info, "invalid combination of flags");
-		      goto error;
-		    }
+                  if (!IS_MODIFIER (spec) &&
+                      !(info.state & (SNV_STATE_BEGIN | SNV_STATE_SPECIFIER)))
+                    {
+                      PRINTF_ERROR (&info, "invalid combination of flags");
+                      goto error;
+                    }
 
-		  /* ...and call the relevant handler. */
-		  if (call_argtype_function (&info, &argtypes, spec) < 0)
-		    goto error;
+                  /* ...and call the relevant handler. */
+                  if (call_argtype_function (&info, &argtypes, spec) < 0)
+                    goto error;
 
-		  info.format++;
-		}
-	      while (info.count >= 0 && IS_MODIFIER (spec));
-	      continue;
-	    }
+                  info.format++;
+                }
+              while (info.count >= 0 && IS_MODIFIER (spec));
+              continue;
+            }
 
-	  /* An escaped CHAR_SPEC: ignore it (by falling through). */
-	  ++info.format;
+          /* An escaped CHAR_SPEC: ignore it (by falling through). */
+          ++info.format;
 
-	  /*NOBREAK*/
+          /*FALLTHROUGH*/
 
-	default:       /* Just a character: ignore it. */
-	  continue;
-	}
+        default:       /* Just a character: ignore it. */
+          continue;
+        }
 
     error:
       /* Get here on error */
@@ -772,11 +770,11 @@ stream_printfv (STREAM *stream, const char *format, snv_constpointer const *ap)
  * @stream: an initialised stream structure.
  * @format: a % delimited format string.
  * @ap: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @ap according to @format, and write
  * the results to @stream.  If @stream is %NULL, only count the
  * number of characters needed to output the format.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -792,6 +790,8 @@ stream_vprintf (STREAM *stream, const char *format, va_list ap)
   return_val_if_fail (format != NULL, SNV_ERROR);
 
   parser_init (&info, format, NULL);
+
+  /* Keep going until the format string runs out! */
   while (*info.format != EOS)
     {
       int ch = (int) *info.format++;
@@ -838,14 +838,14 @@ stream_vprintf (STREAM *stream, const char *format, va_list ap)
 	  /* An escaped CHAR_SPEC: ignore it (by falling through). */
 	  ++info.format;
 
-	  /*NOBREAK*/
+	  /*FALLTHROUGH*/
 
-        default: /* Just a character: ignore it. */
+        default:	/* Just a character: ignore it. */
 	  continue;
 	}
-     
-    error: 
-      /* Get here on error */ 
+
+    error:
+      /* Get here on error */
       info.argc = -1;
       break;
     }
@@ -885,7 +885,7 @@ stream_vprintf (STREAM *stream, const char *format, va_list ap)
           case PA_INT:
 	    args[idx].pa_int = va_arg (ap, int);
             break;
-  
+
           case PA_INT|PA_FLAG_LONG:
 	    args[idx].pa_long_int = va_arg (ap, long int);
             break;
@@ -947,11 +947,11 @@ stream_vprintf (STREAM *stream, const char *format, va_list ap)
  * @stream: an initialised stream structure.
  * @format: a % delimited format string.
  * @va_alist: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @va_alist according to @format, and write
  * the results to @stream.  If @stream is %NULL, only count the
  * number of characters needed to output the format.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -976,10 +976,10 @@ stream_printf (STREAM * stream, const char *format, ...)
  * snv_fdputc: printf.h
  * @ch: A single character to be added to @stream.
  * @stream: The stream in which to write @ch.
- * 
+ *
  * A StreamPut function for use in putting characters
  * into STREAMs holding a file descriptor.
- * 
+ *
  * Return value:
  * The value of @ch that has been put in @stream, or -1 in case of
  * an error (errno will be set to indicate the type of error).
@@ -989,7 +989,9 @@ snv_fdputc (int ch, STREAM *stream)
 {
   static char buf[1] = { 0 };
   buf[0] = (char) ch;
-  return write (SNV_POINTER_TO_INT (stream_details (stream)), buf, 1) ? ch : -1;
+  return
+    write ((int) SNV_POINTER_TO_LONG (stream_details (stream)), buf, (size_t) 1)
+      ? ch : -1;
 }
 
 /**
@@ -997,10 +999,10 @@ snv_fdputc (int ch, STREAM *stream)
  * @fd: an open file descriptor.
  * @format: a % delimited format string.
  * @va_alist: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @va_alist according to @format, and write
  * the results to the file descriptor @fd.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1023,10 +1025,10 @@ snv_dprintf (int fd, const char *format, ...)
  * @fd: an open file descriptor.
  * @format: a % delimited format string.
  * @ap: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @ap according to @format, and write
  * the results to the file descriptor @fd.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1035,7 +1037,7 @@ int
 snv_vdprintf (int fd, const char *format, va_list ap)
 {
   int result;
-  STREAM *out = stream_new (SNV_INT_TO_POINTER (fd),
+  STREAM *out = stream_new (SNV_LONG_TO_POINTER (fd),
 	       		    SNV_UNLIMITED, NULL, snv_fdputc);
 
   result = stream_vprintf (out, format, ap);
@@ -1048,10 +1050,10 @@ snv_vdprintf (int fd, const char *format, va_list ap)
  * @fd: an open file descriptor.
  * @format: a % delimited format string.
  * @args: a vector of argument addresses to match @format.
- * 
+ *
  * Format the elements of @args according to @format, and write
  * the results to file descriptor @fd.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1060,7 +1062,7 @@ int
 snv_dprintfv (int fd, const char *format, snv_constpointer const args[])
 {
   int result;
-  STREAM *out = stream_new (SNV_INT_TO_POINTER (fd),
+  STREAM *out = stream_new (SNV_LONG_TO_POINTER (fd),
 	       		    SNV_UNLIMITED, NULL, snv_fdputc);
 
   result = stream_printfv (out, format, args);
@@ -1073,11 +1075,11 @@ snv_dprintfv (int fd, const char *format, snv_constpointer const args[])
  * snv_fileputc: printf.h
  * @ch: A single character to be added to @stream.
  * @stream: The stream in which to write @ch.
- * 
+ *
  * A StreamPut function for use in putting characters
  * into STREAMs holding a FILE*.
- * 
- * Return value: 
+ *
+ * Return value:
  * The value of @ch that has been put in @stream.
  **/
 int
@@ -1087,14 +1089,21 @@ snv_fileputc (int ch, STREAM *stream)
   return putc (ch, fp);
 }
 
+static int
+snv_fileputc_unlocked (int ch, STREAM *stream)
+{
+  FILE *fp = (FILE *) stream_details (stream);
+  return SNV_PUTC_UNLOCKED (ch, fp);
+}
+
 /**
  * snv_printf: printf.h
  * @format: a % delimited format string.
  * @va_alist: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @va_alist according to @format, and write
  * the results to the standard output stream.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1116,10 +1125,10 @@ snv_printf (const char *format, ...)
  * snv_vprintf: printf.h
  * @format: a % delimited format string.
  * @ap: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @ap according to @format, and write
  * the results to the standard output stream.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1128,9 +1137,12 @@ int
 snv_vprintf (const char *format, va_list ap)
 {
   int result;
-  STREAM *out = stream_new (stdout, SNV_UNLIMITED, NULL, snv_fileputc);
+  STREAM *out = stream_new (stdout, SNV_UNLIMITED, NULL, snv_fileputc_unlocked);
+  int tmp;
+
+  SNV_WITH_LOCKED_FP (stdout, tmp)
+    result = stream_vprintf (out, format, ap);
 
-  result = stream_vprintf (out, format, ap);
   stream_delete (out);
   return result;
 }
@@ -1139,10 +1151,10 @@ snv_vprintf (const char *format, va_list ap)
  * snv_printfv: printf.h
  * @format: a % delimited format string.
  * @args: a vector of argument addresses to match @format.
- * 
+ *
  * Format the elements of @args according to the string @format,
  * and write the result to the standard output stream.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1151,9 +1163,11 @@ int
 snv_printfv (const char *format, snv_constpointer const args[])
 {
   int result;
-  STREAM *out = stream_new (stdout, SNV_UNLIMITED, NULL, snv_fileputc);
+  STREAM *out = stream_new (stdout, SNV_UNLIMITED, NULL, snv_fileputc_unlocked);
+  int tmp;
 
-  result = stream_printfv (out, format, args);
+  SNV_WITH_LOCKED_FP (stdout, tmp)
+    result = stream_printfv (out, format, args);
   stream_delete (out);
   return result;
 }
@@ -1163,10 +1177,10 @@ snv_printfv (const char *format, snv_constpointer const args[])
  * @file: a stdio.h FILE* stream.
  * @format: a % delimited format string.
  * @va_alist: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @va_alist according to @format, and write
  * the results to the @file stream.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1189,10 +1203,10 @@ snv_fprintf (FILE * file, const char *format, ...)
  * @file: a stdio.h FILE* stream.
  * @format: a % delimited format string.
  * @ap: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @ap according to @format, and write
  * the results to the @file stream.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1201,9 +1215,11 @@ int
 snv_vfprintf (FILE *file, const char *format, va_list ap)
 {
   int result;
-  STREAM *out = stream_new (file, SNV_UNLIMITED, NULL, snv_fileputc);
+  STREAM *out = stream_new (file, SNV_UNLIMITED, NULL, snv_fileputc_unlocked);
+  int tmp;
 
-  result = stream_vprintf (out, format, ap);
+  SNV_WITH_LOCKED_FP (file, tmp)
+    result = stream_vprintf (out, format, ap);
   stream_delete (out);
   return result;
 }
@@ -1213,10 +1229,10 @@ snv_vfprintf (FILE *file, const char *format, va_list ap)
  * @file: a stdio.h FILE* stream.
  * @format: a % delimited format string.
  * @args: a vector of argument addresses to match @format.
- * 
+ *
  * Format the elements of @args according to @format, and write
  * the results to @file.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1225,9 +1241,12 @@ int
 snv_fprintfv (FILE *file, const char *format, snv_constpointer const args[])
 {
   int result;
-  STREAM *out = stream_new (file, SNV_UNLIMITED, NULL, snv_fileputc);
+  STREAM *out = stream_new (file, SNV_UNLIMITED, NULL, snv_fileputc_unlocked);
+  int tmp;
+
+  SNV_WITH_LOCKED_FP (file, tmp)
+    result = stream_printfv (out, format, args);
 
-  result = stream_printfv (out, format, args);
   stream_delete (out);
   return result;
 }
@@ -1237,10 +1256,10 @@ snv_fprintfv (FILE *file, const char *format, snv_constpointer const args[])
  * snv_bufputc: printf.h
  * @ch: A single character to be added to @stream.
  * @stream: The stream in which to write @ch.
- * 
+ *
  * A StreamPut function for use in putting characters
  * into STREAMs holding a char buffer.
- * 
+ *
  * Return value:
  * The value of @ch that has been put in @stream.
  **/
@@ -1260,10 +1279,10 @@ snv_bufputc (ch, stream)
  * @buffer: a preallocated char* buffer.
  * @format: a % delimited format string.
  * @va_alist: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @va_alist according to @format, and write
  * the results to the string @buffer.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1286,10 +1305,10 @@ snv_sprintf (char buffer[], const char *format, ...)
  * @buffer: a preallocated char* buffer.
  * @format: a % delimited format string.
  * @ap: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @ap according to @format, and write
  * the results to the string @buffer.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1313,10 +1332,10 @@ snv_vsprintf (char buffer[], const char *format, va_list ap)
  * @buffer: a preallocated char* buffer.
  * @format: a % delimited format string.
  * @args: a vector of argument addresses to match @format.
- * 
+ *
  * Format the elements of @args according to @format, and write
  * the results to the string @buffer.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1341,11 +1360,11 @@ snv_sprintfv (char buffer[], const char *format, snv_constpointer const args[])
  * @limit: the maximum number of characters to write into @buffer.
  * @format: a % delimited format string.
  * @va_alist: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @va_alist according to @format, and write
  * the results to the string @buffer, truncating the formatted string
  * if it reaches @limit characters in length.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1369,11 +1388,11 @@ snv_snprintf (char buffer[], unsigned long limit, const char *format, ...)
  * @limit: the maximum number of characters to write into @buffer.
  * @format: a % delimited format string.
  * @ap: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @ap according to @format, and write
  * the results to the string @buffer, truncating the formatted string
  * if it reaches @limit characters in length.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1396,11 +1415,11 @@ snv_vsnprintf (char buffer[], unsigned long limit, const char *format, va_list a
  * @limit: the maximum number of characters to write into @buffer.
  * @format: a % delimited format string.
  * @args: a vector of argument addresses to match @format.
- * 
+ *
  * Format the elements of @args according to @format, and write
  * the results to the string @buffer, truncating the formatted string
  * if it reaches @limit characters in length.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1422,11 +1441,11 @@ snv_snprintfv (char buffer[], unsigned long limit, const char *format, snv_const
  * snv_filputc: printf.h
  * @ch: A single character to be added to @stream.
  * @stream: The stream in which to write @ch.
- * 
+ *
  * A StreamPut function for use in putting characters
  * into STREAMs holding a Filament*.
- * 
- * Return value: 
+ *
+ * Return value:
  * The value of @ch that has been put in @stream.
  **/
 int
@@ -1442,7 +1461,7 @@ snv_filputc (ch, stream)
  * @result: the address of a char * variable.
  * @format: a % delimited format string.
  * @va_alist: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @va_alist according to @format, and write
  * the results to an internally allocated buffer whose address is
  * stored in @result (and should be freed by the caller) unless
@@ -1450,9 +1469,9 @@ snv_filputc (ch, stream)
  *
  * Yes, this interface is cumbersome and totally useless.  It would
  * have been better to simply return the allocated address, but
- * it turns out that somebody wasn't thinking much when adding 
+ * it turns out that somebody wasn't thinking much when adding
  * asprintf to libiberty a few years ago.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1475,12 +1494,12 @@ snv_asprintf (char **result, const char *format, ...)
  * @result: the address of a char * variable.
  * @format: a % delimited format string.
  * @ap: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @ap according to @format, and write
  * the results to an internally allocated buffer whose address is
  * stored in @result (and should be freed by the caller) unless
  * there is an error.
- * 
+ *
  * Above moaning for asprintf applies here too.
  *
  * Return value:
@@ -1492,7 +1511,7 @@ snv_vasprintf (char **result, const char *format, va_list ap)
 {
   int count_or_errorcode;
   char *base;
-  Filament *fil = filnew (NULL, 0);
+  Filament *fil = filnew (NULL, (size_t)0);
   STREAM *out = stream_new (fil, SNV_UNLIMITED, NULL, snv_filputc);
   count_or_errorcode = stream_vprintf (out, format, ap);
 
@@ -1508,14 +1527,14 @@ snv_vasprintf (char **result, const char *format, va_list ap)
  * @result: the address of a char * variable.
  * @format: a % delimited format string.
  * @args: a vector of argument addresses to match @format.
- * 
+ *
  * Format the elements of @args according to @format, and write
  * the results to an internally allocated buffer whose address is
  * stored in @result (and should be freed by the caller) unless
  * there is an error.
- * 
+ *
  * Above moaning for asprintf applies here too.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1525,7 +1544,7 @@ snv_asprintfv (char **result, const char *format, snv_constpointer const args[])
 {
   int count_or_errorcode;
   char *base;
-  Filament *fil = filnew (NULL, 0);
+  Filament *fil = filnew (NULL, (size_t)0);
   STREAM *out = stream_new (fil, SNV_UNLIMITED, NULL, snv_filputc);
   count_or_errorcode = stream_printfv (out, format, args);
 
@@ -1540,7 +1559,6 @@ snv_asprintfv (char **result, const char *format, snv_constpointer const args[])
  * Local Variables:
  * mode: C
  * c-file-style: "gnu"
- * tab-width: 8
- * indent-tabs-mode: t
+ * indent-tabs-mode: nil
  * End:
  * end of snprintfv/printfv.c */
