@@ -152,12 +152,14 @@ typedef union printf_arg
  *
  * Append an error that will be returned by printf_strerror.
  */
-#define PRINTF_ERROR(pi, str) \
+#define PRINTF_ERROR(pi, str)                                         \
         printf_error(pi, __FILE__, __LINE__, SNV_ASSERT_FCN, str);
+
 typedef int printf_function (STREAM *stream, struct printf_info *pparser,
-							 union printf_arg const * args);
+                             union printf_arg const * args);
+
 typedef int printf_arginfo_function (struct printf_info *pparser, size_t n,
-									 int *argtypes);
+                                     int *argtypes);
 
 /**
  * spec_entry:
@@ -247,18 +249,58 @@ enum
  **/
 #define SNV_EMIT(ch, stream, count) \
   SNV_STMT_START { \
-    if (stream) \
+    if ((stream)) \
       { \
-	if (count >= 0) \
+	if ((count) >= 0) \
 	  { \
-	    int m_status = stream_put((unsigned char)(ch), stream); \
-	    count = m_status < 0 ? m_status : count + m_status; \
+	    int m_status = stream_put((unsigned char) (ch), (stream)); \
+	    (count) = m_status < 0 ? m_status : (count) + m_status; \
 	  } \
       } \
-    else count++; \
+    else \
+      { \
+        (void)(ch); \
+	(count)++; \
+      } \
   } SNV_STMT_END
 
-#line 261 "./printf.in"
+#line 267 "./printf.in"
+/**
+ * printf_generic_info:   
+ * @pinfo: the current state information for the format
+ * string parser.
+ * @n: the number of available slots in the @argtypes array
+ * @argtypes: the pointer to the first slot to be filled by the
+ * function
+ *
+ * An example implementation of a %printf_arginfo_function, which
+ * takes the basic type from the type given in the %spec_entry
+ * and adds flags depending on what was parsed (e.g. %PA_FLAG_SHORT
+ * is %pparser->is_short and so on).
+ *
+ * Return value:
+ * Always 1.
+ */
+extern int printf_generic_info (struct printf_info *const pinfo, size_t n, int *argtypes);
+
+
+/**
+ * printf_generic:   
+ * @stream: the stream (possibly a struct printfv_stream appropriately
+ * cast) on which to write output.
+ * @pinfo: the current state information for the format string parser.
+ * @args: the pointer to the first argument to be read by the handler
+ *
+ * An example implementation of a %printf_function, used to provide easy
+ * access to justification, width and precision options.
+ *
+ * Return value:
+ * The number of characters output.
+ **/
+extern int printf_generic (STREAM *stream, struct printf_info *const pinfo, union printf_arg const *args);
+
+
+#line 268 "./printf.in"
 /**
  * register_printf_function:  
  * @spec: the character which will trigger @func, cast to an unsigned int.
@@ -746,66 +788,30 @@ extern int snv_vasprintf (char **result, const char *format, va_list ap);
 extern int snv_asprintfv (char **result, const char *format, snv_constpointer const args[]);
 
 
-#line 262 "./printf.in"
-/**
- * printf_generic_info:   
- * @pinfo: the current state information for the format
- * string parser.
- * @n: the number of available slots in the @argtypes array
- * @argtypes: the pointer to the first slot to be filled by the
- * function
- *
- * An example implementation of a %printf_arginfo_function, which
- * takes the basic type from the type given in the %spec_entry
- * and adds flags depending on what was parsed (e.g. %PA_FLAG_SHORT
- * is %pparser->is_short and so on).
- *
- * Return value:
- * Always 1.
- */
-extern int printf_generic_info (struct printf_info *const pinfo, size_t n, int *argtypes);
-
-
-/**
- * printf_generic:   
- * @stream: the stream (possibly a struct printfv_stream appropriately
- * cast) on which to write output.
- * @pinfo: the current state information for the format string parser.
- * @args: the pointer to the first argument to be read by the handler
- *
- * An example implementation of a %printf_function, used to provide easy
- * access to justification, width and precision options.
- *
- * Return value:
- * The number of characters output.
- **/
-extern int printf_generic (STREAM *stream, struct printf_info *const pinfo, union printf_arg const *args);
-
-
-#line 263 "./printf.in"
+#line 269 "./printf.in"
 
 /* If you don't want to use snprintfv functions for *all* of your string
    formatting API, then define COMPILING_SNPRINTFV_C and use the snv_
    prefix for the entry points below. */
 #ifndef COMPILING_PRINTF_C
-#undef  printf
-#undef  vprintf
-#undef  dprintf
-#undef  vdprintf
-#undef  fprintf
-#undef  vfprintf
-#undef  sprintf
-#undef  vsprintf
-#undef  snprintf
-#undef  vsnprintf
-#undef  asprintf
-#undef  vasprintf
-#undef  asprintfv
-#undef  dprintfv
-#undef  fprintfv
-#undef  sprintfv
-#undef  printfv
-#undef  snprintfv
+#undef printf
+#undef vprintf
+#undef dprintf
+#undef vdprintf
+#undef fprintf
+#undef vfprintf
+#undef sprintf
+#undef vsprintf
+#undef snprintf
+#undef vsnprintf
+#undef asprintf
+#undef vasprintf
+#undef asprintfv
+#undef dprintfv
+#undef fprintfv
+#undef sprintfv
+#undef printfv
+#undef snprintfv
 
 #define printf          snv_printf
 #define vprintf         snv_vprintf
